@@ -1,9 +1,4 @@
 <?php
-/**
- * Prepare the test setup.
- */
-require_once __DIR__ . '/Autoload.php';
-
 /**
  * @author     Jan Schneider <jan@horde.org>
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
